====
TODO
====
  
  Things that would be great to have but I haven't gotten to do them yet.

Code
----

* Migrating to ``configparser`` and throwing out FunkyConfigParser would do much
  good
   
* There are not enough unit tests

* No examples in the code

Docs
----

* Bits documented only by means of API, no proper introduction:

  * forms

  * models

* Bits undocumented:

  * orderedset

  * score
    
  * tags

* There is no clear roadmap of where this project is heading

* No FAQ, Tutorial

Community
---------

* There is no community

* Some publicity would be helpful
